ask_rex: Ask Rex

View source: R/ask_rex.R

ask_rexR Documentation

Ask Rex

Description

This function lets you ask dino Rex for help. You can try to ask for specific functions and topics or just use the function as-is for some motivational words of encouragement. :)

Usage

ask_rex(topic = "?")

Arguments

topic

What you want to know about; either leave it blank for motivation or specify 'ttest', 'mean'... Input must be in quotes!

Value

Returns advice and explanations on R; sometimes Rex asks follow-up questions

Examples

# Get motivation
ask_rex()

# Get specific information
ask_rex("mean")
ask_rex(topic = "ttest")


rextor documentation built on May 21, 2026, 5:09 p.m.