informed_consent: Informed Consent Filter

View source: R/informed_consent.R

informed_consentR Documentation

Description

One of the best practices in data collection is including and informed consent question. With this function you can automatically filter out rows where participants did not explicitly consent to their data being used.

Usage

informed_consent(dataframe, varname = "informedconsent")

Arguments

dataframe

A dataframe of data collected with 'WEXTOR'

varname

character. Variable name of informed consent variable. Defaults to "informedconsent".

Value

Returns data with cases filtered out that did not check the informed consent box

Examples


data <- data.frame(informedconsent = c("checked", "not checked", "checked"))
informed_only <- informed_consent(data) 


rextor documentation built on May 21, 2026, 5:09 p.m.