path_to_file: Get file path to example data file

View source: R/utility.R

path_to_fileR Documentation

Get file path to example data file

Description

This function makes the example data from the BiFiX study (submitted for publication in BRM) easy to access.

Usage

path_to_file(path = NULL)

Arguments

path

Name of file in quotes with extension; "BiFiX_data_raw.csv" will work. If NULL, the example file will be listed.

Value

Gives the path to the example file included in the package. Meant for use in read_WEXTOR().

This function is adapted from palmerpenguins (which is adapted from readxl::readxl_example()).

Examples

path_to_file()
path_to_file("BiFiX_data_raw.csv")
head(read.csv(path_to_file("BiFiX_data_raw.csv")))

rextor documentation built on May 21, 2026, 5:09 p.m.