| theme_wob | R Documentation |
This theme option is built to be used with a ggplot2 plot.
It offers several options for a dark theme, i.e. dark background with light writing.
theme_wob(max_font_size = 14, contrast = "high")
max_font_size |
Maximum font size, used for the plot title (other font sizes are automatically adjusted accordingly). |
contrast |
Character to indicate the choice of color palette depending on the desired contrast.
Defaults to |
Plot theme.
# Load the data
data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
# Create any plot
library(ggplot2)
ggplot(data, aes(age, color = gender, fill = gender)) +
geom_density(alpha = .5) +
theme_wob(contrast = "rex")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.