| ask_rex | R Documentation |
This function lets you ask dino Rex for help. You can try to ask for specific functions and topics or just use the function as-is for some motivational words of encouragement. :)
ask_rex(topic = "?")
topic |
What you want to know about; either leave it blank for motivation or specify 'ttest', 'mean'... Input must be in quotes! |
Returns advice and explanations on R; sometimes Rex asks follow-up questions
# Get motivation
ask_rex()
# Get specific information
ask_rex("mean")
ask_rex(topic = "ttest")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.