Check whether a plausibility condition is satisfied
check_ok.RdReturns a logical vector indicating whether a given check column equals "ok".
If the column does not exist in the data, all cases are treated as passing.
Details
Used inside the plausicheck() function.