| getmode | R Documentation |
The mode is the number that appears the most often in a vector or variable. This measure is especially important for nominal variables since the mean or median cannot meaningfully be reported.
getmode(v)
v |
a vector of variable in dataframe |
Returns the mode of v, i.e., the value occurring most often
vec <- c("A", "A", "B")
getmode(vec)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.