View source: R/informed_consent.R
| informed_consent | R Documentation |
One of the best practices in data collection is including and informed consent question. With this function you can automatically filter out rows where participants did not explicitly consent to their data being used.
informed_consent(dataframe, varname = "informedconsent")
dataframe |
A dataframe of data collected with 'WEXTOR' |
varname |
character. Variable name of informed consent variable. Defaults to "informedconsent". |
Returns data with cases filtered out that did not check the informed consent box
data <- data.frame(informedconsent = c("checked", "not checked", "checked"))
informed_only <- informed_consent(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.