| namepref0 | R Documentation |
This function adds the new prefix and changes the dataframe's names to the new ones.
namepref0(dataframe, pref_new)
dataframe |
A dataframe |
pref_new |
New prefix character to add to all variable namess in the dataframe have |
Returns dataframe with all variables renamed to start with the new prefix.
bla <- tibble::tibble(x_ar = 1:5, y_ar = 6:10)
blo <- namepref0(bla, "var")
names(bla)
names(blo)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.