| path_to_file | R Documentation |
This function makes the example data from the BiFiX study (submitted for publication in BRM) easy to access.
path_to_file(path = NULL)
path |
Name of file in quotes with extension;
|
Gives the path to the example file included in the package. Meant for use in read_WEXTOR().
This function is adapted from palmerpenguins (which is adapted from readxl::readxl_example()).
path_to_file()
path_to_file("BiFiX_data_raw.csv")
head(read.csv(path_to_file("BiFiX_data_raw.csv")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.