| removepref | R Documentation |
This function strips the old prefix from the server variable names of the dataframe. It identifies such variables that start with ".wx.#." where # stands for any number, or simply ".wx." and then removes these prefixes for more easily legible and usable variable names in your data!
removepref(dataframe)
dataframe |
A dataframe, usefully containing variables that have the server prefix ".wx.#." |
Returns dataframe with those variables renamed that start with the old prefix.
bli <- tibble::tibble(.wx.1.ar = 1:5, y_ar = 6:10, .wx.z = 11:15)
blu <- removepref(bli)
names(bli)
names(blu)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.