View source: R/serious_check.R
| serious_check | R Documentation |
Filter your data frame by your item for the "seriousness check". If the data comes from 'WEXTOR' with no previous changes to the automatically created variable, you will be able to accept all defaults in this function and simply input the data frame.
serious_check(dataframe, varname = "seriousness", keep = "participate")
dataframe |
Data which contains a variable for the seriousness check. |
varname |
Variable for the seriousness check. Defaults to |
keep |
Values from the variable to keep. Defaults to |
Filtered data
data <- read_WEXTOR(path_to_file("BiFiX_data_raw.csv"))
serious_only <- serious_check(data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.